operator [] method

V? operator [](
  1. Object? k$1
)
override

The value for the given key, or null if key is not in the map.

Some maps allow null as a value. For those maps, a lookup using this operator cannot distinguish between a key not being in the map, and the key being there with a null value. Methods like containsKey or putIfAbsent can be used if the distinction is important.

Implementation

V? operator [](dc.Object? k$1, ){
final lcoc_core.HashRankedWideTreapMap<K, V> o7766$1=this;
final dc.dynamic k7767$1=k$1;
if((o7766$1 is lcoc_core.ILookup$iface)){
return ((o7766$1 as lcoc_core.ILookup$iface).$_lookup$2(k7767$1, null, ));
}
return ((lcoc_core.ILookup.extensions(o7766$1, ) as lcoc_core.ILookup$ext).$_lookup$2(o7766$1, k7767$1, null, ));
}