IWatchable$ext class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$_add_watch$2(
dynamic $this_$2, dynamic key$3, dynamic f$2) → dynamic -
$_notify_watches$2(
dynamic $this_$1, dynamic oldval$2, dynamic newval$2) → dynamic -
$_remove_watch$1(
dynamic $this_$3, dynamic key$4) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited