compareTo method
Compares this object to another object.
Returns a value like a Comparator when comparing this to other.
That is, it returns a negative integer if this is ordered before other,
a positive integer if this is ordered after other,
and zero if this and other are ordered together.
The other argument must be a value that is comparable to this object.
Implementation
dc.int compareTo(dc.dynamic y$1, ){
if(lcoc_core.vector$QMARK_(y$1, )){
return lcoc_core.compare_indexed(this, y$1, );
}
throw dc.ArgumentError((lcoc_core.str.$_invoke$4("Cannot compare ", this, " to ", y$1, )), );
}