Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$_sorted_rseq$3(dynamic coll$2, dynamic from$4, dynamic to$4, dynamic flags$4)
→ dynamic
-
-
$_sorted_seq$3(dynamic coll$1, dynamic from$3, dynamic to$3, dynamic flags$3)
→ dynamic
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited